@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyPromptService.cpp,v 1.10 2006/03/08 11:03:24 chpe Exp $
+ *  $Id: EphyPromptService.cpp,v 1.10.2.1 2006/04/01 12:00:16 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -457,11 +457,10 @@ EnableResponse (GtkDialog *aDialog)
 }
 
 static void
-RemoveTimeout (GObject *aDialog)
+RemoveTimeout (gpointer idptr)
 {
-	guint timeout;
+	guint timeout = GPOINTER_TO_UINT (idptr);
 
-	timeout = GPOINTER_TO_UINT (g_object_get_data (aDialog, TIMEOUT_DATA_KEY));
 	g_return_if_fail (timeout != 0);
 
 	g_source_remove (timeout);
