@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.40 2006/02/02 22:25:18 chpe Exp $
+ *  $Id: GtkNSSDialogs.cpp,v 1.41.2.2 2006/05/15 18:32:49 chpe Exp $
  */
 
 /*
@@ -45,8 +45,12 @@
 #include <nsIASN1Sequence.h>
 #include <nsICRLInfo.h>
 #include <nsISimpleEnumerator.h>
-#include <nsIArray.h>
 #include <nsIDOMWindow.h>
+#include <nsIArray.h>
+#ifdef HAVE_NSIMUTABLEARRAY_H
+#include <nsIMutableArray.h>
+#endif
+
 #undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
 #define MOZILLA_INTERNAL_API 1
@@ -98,9 +102,9 @@ GtkNSSDialogs::~GtkNSSDialogs ()
 {
 }
 
-NS_IMPL_ISUPPORTS2 (GtkNSSDialogs, 
-		    nsICertificateDialogs,
-		    nsIBadCertListener)
+NS_IMPL_THREADSAFE_ISUPPORTS2 (GtkNSSDialogs, 
+			       nsICertificateDialogs,
+			       nsIBadCertListener)
 
 /**
  *  Call the mozilla service to display a certificate
@@ -111,7 +115,7 @@ view_certificate (nsIInterfaceRequestor *ctx, nsIX509Cert *cert)
 	nsresult rv;
 	nsCOMPtr<nsICertificateDialogs> certDialogs =
 		do_GetService (NS_CERTIFICATEDIALOGS_CONTRACTID, &rv);
-	g_return_if_fail (NS_SUCCEEDED (rv));
+	NS_ENSURE_SUCCESS (rv, );
 
 	certDialogs->ViewCert (ctx, cert);
 }
@@ -224,7 +228,7 @@ display_cert_warning_box (nsIInterfaceRequestor *ctx,
 	
 	dialog = gtk_dialog_new_with_buttons ("", gparent,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
-					      NULL);
+					      (char *) NULL);
 	if (gparent)
 	{
 		gtk_window_group_add_window (ephy_gui_ensure_window_group (gparent),
@@ -494,7 +498,7 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_OK,
 					      GTK_RESPONSE_OK,
-					      NULL);
+					      (char *) NULL);
 
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
@@ -559,7 +563,7 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 					      NSSDIALOG_RESPONSE_VIEW_CERT,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      _("_Trust CA"),	GTK_RESPONSE_ACCEPT,
-					      NULL);
+					      (char *) NULL);
 
 	if (gparent)
 	{
@@ -642,7 +646,7 @@ GtkNSSDialogs::NotifyCACertExists (nsIInterfaceRequestor *ctx)
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_OK,
 					      GTK_RESPONSE_OK,
-					      NULL);
+					      (char *) NULL);
 
 	if (gparent)
 	{
@@ -774,7 +778,7 @@ GtkNSSDialogs::SetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CANCEL,
 					      GTK_RESPONSE_CANCEL,
-					      NULL);
+					      (char *) NULL);
 
 	if (gparent)
 	{
@@ -897,7 +901,7 @@ GtkNSSDialogs::GetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      _("I_mport Certificate"), GTK_RESPONSE_OK,
-					      NULL);
+					      (char *) NULL);
 
 	if (gparent)
 	{
@@ -999,7 +1003,7 @@ GtkNSSDialogs::CrlImportStatusDialog(nsIInterfaceRequestor *ctx, nsICRLInfo *crl
 					      GTK_WINDOW (gparent),
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
-					      NULL);
+					      (char *) NULL);
 
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Certificate Revocation List Imported"));
@@ -1278,7 +1282,7 @@ setup_view_cert_tree (GtkWidget *dialog, GladeXML*gxml, nsIArray *certChain)
 						     0, "Certificate",
 						     renderer,
 						     "text", 0,
-						     NULL);
+						     (char *) NULL);
 
 	GtkTreeSelection *select = gtk_tree_view_get_selection (GTK_TREE_VIEW (chain_tree_view));
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
@@ -1299,7 +1303,7 @@ setup_view_cert_tree (GtkWidget *dialog, GladeXML*gxml, nsIArray *certChain)
 						     0, "Certificate Field",
 						     renderer,
 						     "text", 0,
-						     NULL);
+						     (char *) NULL);
 
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (field_tree_view));
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
