@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-prefs.h,v 1.33 2006/01/25 21:52:26 chpe Exp $
+ *  $Id: ephy-prefs.h,v 1.33.2.1 2006/04/09 19:54:07 chpe Exp $
  */
 
 #ifndef EPHY_PREFS_H
@@ -38,6 +38,9 @@ G_BEGIN_DECLS
 #define CONF_DESKTOP_IS_HOME_DIR		"/apps/nautilus/preferences/desktop_is_home_dir"
 #define CONF_NETWORK_MANAGED			"/apps/epiphany/general/managed_network"
 
+/* i18n pref */
+#define CONF_GECKO_ENABLE_PANGO			"/apps/epiphany/web/enable_pango"
+
 /* Directories */
 #define CONF_STATE_SAVE_DIR		"/apps/epiphany/directories/save"
 #define CONF_STATE_SAVE_IMAGE_DIR	"/apps/epiphany/directories/saveimage"
