@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-entry.h,v 1.20 2005/07/26 14:41:39 chpe Exp $
+ *  $Id: ephy-location-entry.h,v 1.21 2005/10/06 18:28:55 chpe Exp $
  */
 
 #ifndef EPHY_LOCATION_ENTRY_H
@@ -88,6 +88,9 @@ GtkWidget      *ephy_location_entry_get_entry		(EphyLocationEntry *entry);
 void		ephy_location_entry_set_favicon		(EphyLocationEntry *entry,
 							 GdkPixbuf *pixbuf);
 
+void		ephy_location_entry_set_secure		(EphyLocationEntry *entry,
+							 gboolean secure);
+
 void		ephy_location_entry_set_show_lock	(EphyLocationEntry *entry,
 							 gboolean show_lock);
 
