@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,6 +15,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-bookmarks-import.h,v 1.9 2005/01/19 21:39:01 chpe Exp $
  */
 
 #ifndef EPHY_BOOKMARKS_IMPORT_H
@@ -24,8 +27,9 @@
 G_BEGIN_DECLS
 
 #define MOZILLA_BOOKMARKS_DIR	".mozilla"
-#define FIREBIRD_BOOKMARKS_DIR	".phoenix"
-#define FIREFOX_BOOKMARKS_DIR   ".firefox"
+#define FIREFOX_BOOKMARKS_DIR_0	".phoenix"
+#define FIREFOX_BOOKMARKS_DIR_1	".firefox"
+#define FIREFOX_BOOKMARKS_DIR_2	".mozilla/firefox"
 #define GALEON_BOOKMARKS_DIR	".galeon"
 #define KDE_BOOKMARKS_DIR	".kde/share/apps/konqueror"
 
