@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-python.h,v 1.1 2005/05/21 13:58:23 chpe Exp $
+ *  $Id: ephy-python.h,v 1.2 2005/07/29 19:53:46 chpe Exp $
  */
 
 #ifndef EPHY_PYTHON_H
@@ -25,7 +25,11 @@
 
 G_BEGIN_DECLS
 
-void ephy_python_init (void);
+void ephy_python_init	     (void);
+
+void ephy_python_shutdown    (void);
+
+void ephy_python_schedule_gc (void);
 
 G_END_DECLS
 
