@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-statusbar.h,v 1.8 2005/07/29 20:24:23 chpe Exp $
+ *  $Id: ephy-statusbar.h,v 1.9 2006/01/18 14:21:11 chpe Exp $
  */
 
 #ifndef EPHY_STATUSBAR_H
@@ -65,6 +65,9 @@ GtkTooltips  *ephy_statusbar_get_tooltips		(EphyStatusbar *statusbar);
 
 GtkWidget    *ephy_statusbar_get_security_frame		(EphyStatusbar *statusbar);
 
+void	      ephy_statusbar_set_caret_mode		(EphyStatusbar *statusbar,
+							 gboolean enabled);
+
 void          ephy_statusbar_set_security_state		(EphyStatusbar *statusbar,
 							 const char *stock_id,
 							 const char *tooltip);
